@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -33,6 +33,7 @@ import types
 import Command
 import FileUtilities
 import General
+import Special
 
 from Common import _
 
@@ -93,7 +94,7 @@ class FileActionProvider(ActionProvider):
         assert(isinstance(self.regex, (str, unicode, types.NoneType)))
         self.search = action_element.getAttribute('search')
         self.path = os.path.expanduser(os.path.expandvars( \
-        action_element.getAttribute('path')))
+            action_element.getAttribute('path')))
         self.ds = {}
         if 'deep' == self.search:
             self.ds['regex'] = self.regex
@@ -116,12 +117,14 @@ class FileActionProvider(ActionProvider):
                 yield path
 
         def get_walk_all(top):
-            for path in FileUtilities.children_in_directory(top, True):
-                yield path
+            for expanded in glob.iglob(top):
+                for path in FileUtilities.children_in_directory(expanded, True):
+                    yield path
 
         def get_walk_files(top):
-            for path in FileUtilities.children_in_directory(top, False):
-                yield path
+            for expanded in glob.iglob(top):
+                for path in FileUtilities.children_in_directory(expanded, False):
+                    yield path
 
         if 'deep' == self.search:
             raise StopIteration
@@ -171,6 +174,7 @@ class AptAutoclean(ActionProvider):
                 'apt-get autoclean')
 
 
+
 class AptAutoremove(ActionProvider):
     """Action to run 'apt-get autoremove'"""
     action_key = 'apt.autoremove'
@@ -187,6 +191,30 @@ class AptAutoremove(ActionProvider):
                 'apt-get autoremove')
 
 
+class ChromeAutofill(FileActionProvider):
+    """Action to clean 'autofill' table in Google Chrome/Chromium"""
+    action_key = 'chrome.autofill'
+
+    def get_commands(self):
+        for path in self.get_paths():
+            yield Command.Function( \
+                path, \
+                Special.delete_chrome_autofill, \
+               _('Clean file'))
+
+
+class ChromeKeywords(FileActionProvider):
+    """Action to clean 'keywords' table in Google Chrome/Chromium"""
+    action_key = 'chrome.keywords'
+
+    def get_commands(self):
+        for path in self.get_paths():
+            yield Command.Function( \
+                path, \
+                Special.delete_chrome_keywords, \
+               _('Clean file'))
+
+
 class Delete(FileActionProvider):
     """Action to delete files"""
     action_key = 'delete'
@@ -198,6 +226,38 @@ class Delete(FileActionProvider):
 
 
 
+class Ini(FileActionProvider):
+    """Action to clean .ini configuration files"""
+    action_key = 'ini'
+
+    def __init__(self, action_element):
+        FileActionProvider.__init__(self, action_element)
+        self.section = action_element.getAttribute('section')
+        self.parameter = action_element.getAttribute('parameter')
+        if self.parameter == "":
+            self.parameter = None
+
+
+    def get_commands(self):
+        for path in self.get_paths():
+            yield Command.Ini(path, self.section, self.parameter)
+
+
+class Json(FileActionProvider):
+    """Action to clean JSON configuration files"""
+    action_key = 'json'
+
+    def __init__(self, action_element):
+        FileActionProvider.__init__(self, action_element)
+        self.address = action_element.getAttribute('address')
+
+
+    def get_commands(self):
+        for path in self.get_paths():
+            yield Command.Json(path, self.address)
+
+
+
 class Shred(FileActionProvider):
     """Action to shred files (override preference)"""
     action_key = 'shred'
