@@ -2,7 +2,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -31,9 +31,8 @@ import os
 import sys
 
 from Cleaner import backends
-from Common import _
-import Common
-import General
+from Common import _, APP_VERSION
+import Options
 import Worker
 
 
@@ -80,14 +79,15 @@ def init_cleaners():
     """Prepare the cleaners for use"""
     import CleanerML
     CleanerML.load_cleaners()
+    if 'nt' == os.name:
+        import Winapp
+        Winapp.load_cleaners()
 
 
 def cleaners_list():
     """Yield each cleaner-option pair"""
     init_cleaners()
-    cleaners = []
     for key in sorted(backends):
-        c_name = backends[key].get_name()
         c_id = backends[key].get_id()
         for (o_id, o_name) in backends[key].get_options():
             yield "%s.%s" % (c_id, o_id)
@@ -107,16 +107,22 @@ def preview_or_delete(operations, really_delete):
         pass
 
 
-def args_to_operations(args):
+def args_to_operations(args, preset):
     """Read arguments and return list of operations"""
     init_cleaners()
     operations = {}
+    if preset:
+        # restore presets from the GUI
+        for key in sorted(backends):
+            c_id = backends[key].get_id()
+            for (o_id, o_name) in backends[key].get_options():
+                if Options.options.get_tree(c_id, o_id):
+                    args.append('.'.join([ c_id, o_id ]) )
     for arg in args:
         if 2 != len(arg.split('.')):
             print _("not a valid cleaner: %s") % arg
             continue
         (cleaner_id, option_id) = arg.split('.')
-        default = False
         # enable all options (for example, firefox.*)
         if '*' == option_id:
             if operations.has_key(cleaner_id):
@@ -151,6 +157,8 @@ def process_cmd_line():
         help = _("show system information"))
     parser.add_option("-p", "--preview", action = "store_true",
         help = _("preview files to be deleted and other changes"))
+    parser.add_option("--preset", action="store_true",
+        help = _("use options set in the graphical interface"))
     parser.add_option("-v", "--version", action = "store_true",
         help = _("output version information and exit"))
     parser.add_option('-o', '--overwrite', action = 'store_true',
@@ -159,23 +167,22 @@ def process_cmd_line():
     if options.version:
         print """
 BleachBit version %s
-Copyright (C) 2010 Andrew Ziem.  All rights reserved.
+Copyright (C) 2011 Andrew Ziem.  All rights reserved.
 License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>.
 This is free software: you are free to change and redistribute it.
-There is NO WARRANTY, to the extent permitted by law.""" % Common.APP_VERSION
+There is NO WARRANTY, to the extent permitted by law.""" % APP_VERSION
         sys.exit(0)
     if options.list_cleaners:
         list_cleaners()
         sys.exit(0)
     if options.preview:
-        operations = args_to_operations(args)
+        operations = args_to_operations(args, options.preset)
         preview_or_delete(operations, False)
         sys.exit(0)
     if options.overwrite:
-        import Options
         Options.options.set('shred', True, commit = False)
     if options.delete:
-        operations = args_to_operations(args)
+        operations = args_to_operations(args, options.preset)
         preview_or_delete(operations, True)
         sys.exit(0)
     if options.sysinfo:
