@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -39,6 +39,7 @@ import traceback
 
 import Command
 import FileUtilities
+import General
 import Memory
 import Special
 
@@ -85,7 +86,7 @@ class Cleaner:
         for (option_id, __name) in self.get_options():
             try:
                 for cmd in self.get_commands(option_id):
-                    for ret in cmd.execute(False):
+                    for dummy in cmd.execute(False):
                         return False
                 for ds in self.get_deep_scan(option_id):
                     if isinstance(ds, dict):
@@ -155,9 +156,7 @@ class Cleaner:
                     print "debug: process '%s' is running" % pathname
                     return True
             elif 'exe' == test and 'nt' == os.name:
-                print 'debug: type(%s) = %s' % (pathname, type(pathname))
                 for p in Windows.enumerate_processes():
-                    print 'debug: type(%s) = %s' % (p, type(p))
                     if p == pathname:
                         print "debug: process '%s' is running" % pathname
                         return True
@@ -187,12 +186,12 @@ class Firefox(Cleaner):
         Cleaner.__init__(self)
         self.add_option('cache', _('Cache'), _('Delete the web cache, which reduces time to display revisited pages'))
         self.add_option('cookies', _('Cookies'), _('Delete cookies, which contain information such as web site preferences, authentication, and tracking identification'))
+        # TRANSLATORS: DOM = Document Object Model.
+        self.add_option('dom', _('DOM Storage'), _('Delete HTML5 cookies'))
         self.add_option('download_history', _('Download history'), _('List of files downloaded'))
         self.add_option('forms', _('Form history'), _('A history of forms entered in web sites and in the Search bar'))
         self.add_option('session_restore', _('Session restore'), _('Loads the initial session after the browser closes or crashes'))
         self.add_option('passwords', _('Passwords'), _('A database of usernames and passwords as well as a list of sites that should not store passwords'))
-        self.add_option('places', _('Places'), _('A database of URLs including bookmarks, favicons, and a history of visited web sites'))
-        self.set_warning('places', _('This option deletes all bookmarks.'))
         self.add_option('url_history', _('URL history'), _('List of visited web pages'))
         self.add_option('vacuum', _('Vacuum'), _('Clean database fragmentation to reduce space and improve speed without removing any data'))
 
@@ -221,7 +220,7 @@ class Firefox(Cleaner):
         if 'posix' == os.name:
             cache_base = self.profile_dir
         elif 'nt' == os.name:
-            cache_base = "$USERPROFILE\\Local Settings\\Application Data\\Mozilla\\Firefox\\Profiles\\*"
+            cache_base = "$localappdata\\Mozilla\\Firefox\\Profiles\\*"
         if 'cache' == option_id:
             dirs = FileUtilities.expand_glob_join(cache_base, "Cache*")
             dirs += FileUtilities.expand_glob_join(cache_base, "OfflineCache")
@@ -233,6 +232,10 @@ class Firefox(Cleaner):
         if 'cookies' == option_id:
             files += FileUtilities.expand_glob_join(self.profile_dir, "cookies.txt")
             files += FileUtilities.expand_glob_join(self.profile_dir, "cookies.sqlite")
+        # DOM storage
+        if 'dom' == option_id:
+            files += FileUtilities.expand_glob_join(self.profile_dir, "webappsstore.sqlite")
+
         # download history
         if 'download_history' == option_id:
             # Firefox version 1
@@ -248,13 +251,6 @@ class Firefox(Cleaner):
             files += FileUtilities.expand_glob_join(self.profile_dir, "signons.txt")
             files += FileUtilities.expand_glob_join(self.profile_dir, "signons[2-3].txt")
             files += FileUtilities.expand_glob_join(self.profile_dir, "signons.sqlite")
-        # places database
-        if 'places' == option_id:
-            # Firefox version 3
-            files += FileUtilities.expand_glob_join(self.profile_dir, "places.sqlite")
-            files += FileUtilities.expand_glob_join(self.profile_dir, "places.sqlite-journal")
-            files += FileUtilities.expand_glob_join(self.profile_dir, "bookmarkbackups/*ookmark*json")
-            # see also option 'url_history'
         # session restore
         if 'session_restore' == option_id:
             files += FileUtilities.expand_glob_join(self.profile_dir, "sessionstore.js")
@@ -346,42 +342,6 @@ class OpenOfficeOrg(Cleaner):
                             _('Delete the usage history'))
 
 
-class rpmbuild(Cleaner):
-    """Delete the rpmbuild build directory"""
-
-    def __init__(self):
-        Cleaner.__init__(self)
-        self.options = {}
-        self.add_option('cache', _('Cache'), _('Delete the cache'))
-
-    def get_description(self):
-        return _("Delete the files in the rpmbuild build folder")
-
-    def get_id(self):
-        return 'rpmbuild'
-
-    def get_name(self):
-        return "rpmbuild"
-
-    def get_commands(self, option_id):
-        if not 'cache' == option_id:
-            raise StopIteration
-
-        dirnames = set([ os.path.expanduser("~/rpmbuild/BUILD/") ])
-        try:
-            args = ["rpm", "--eval", "%_topdir"]
-            dirname = subprocess.Popen(args, stdout=subprocess.PIPE).\
-                communicate()[0]
-        except:
-            print "warning: exception '%s' running '%s'" % \
-                (str(sys.exc_info()[1]), " ".join(args))
-        else:
-            dirnames.add(dirname + "/BUILD")
-        for dirname in dirnames:
-            for filename in children_in_directory(dirname, True):
-                yield Command.Delete(filename)
-
-
 class System(Cleaner):
     """System in general"""
 
@@ -399,6 +359,7 @@ class System(Cleaner):
             # TRANSLATORS: Localizations are files supporting specific
             # languages, so applications appear in Spanish, etc.
             self.add_option('localizations', _('Localizations'), _('Delete files for unwanted languages'))
+            self.set_warning('localizations', _("Configure this option in the preferences."))
             # TRANSLATORS: 'Rotated logs' refers to old system log files.
             # Linux systems often have a scheduled job to rotate the logs
             # which means compress all except the newest log and then delete
@@ -407,19 +368,27 @@ class System(Cleaner):
             self.add_option('recent_documents', _('Recent documents list'), _('Delete the list of recently used documents'))
             self.add_option('trash', _('Trash'), _('Empty the trash'))
         if 'linux2' == sys.platform:
-            # TRANSLATORS: 'Free' is an adjective and could be translated
-            # 'unallocated.'
-            self.add_option('memory', _('Memory'), _('Wipe the swap and free memory'))
+            self.add_option('memory', _('Memory'), \
+            # TRANSLATORS: 'free' means 'unallocated'
+               _('Wipe the swap and free memory'))
             self.set_warning('memory', _('This option is experimental and may cause system problems.'))
         if 'nt' == os.name:
             self.add_option('logs', _('Logs'), _('Delete the logs'))
+            self.add_option('memory_dump', _('Memory dump'), _('Delete the file memory.dmp'))
             self.add_option('muicache', 'MUICache', _('Delete the cache'))
             # TRANSLATORS: Prefetch is Microsoft Windows jargon.
             self.add_option('prefetch', _('Prefetch'), _('Delete the cache'))
             self.add_option('recycle_bin', _('Recycle bin'), _('Empty the recycle bin'))
+            # TRANSLATORS: 'Update' is a noun, and 'Update uninstallers' is an option to delete
+            # the uninstallers for software updates.
+            self.add_option('updates', _('Update uninstallers'), _('Delete uninstallers for Microsoft updates including hotfixes, service packs, and Internet Explorer updates'))
+            self.set_warning('updates', _('This option is experimental and may cause system problems.'))
         if HAVE_GTK:
             self.add_option('clipboard', _('Clipboard'), _('The desktop environment\'s clipboard used for copy and paste operations'))
-        self.add_option('free_disk_space', _('Free disk space'), _('Overwrite free disk space to hide deleted files'))
+        # TRANSLATORS: 'free' means 'unallocated'
+        self.add_option('free_disk_space', _('Free disk space'), \
+            # TRANSLATORS: 'free' means 'unallocated'
+            _('Overwrite free disk space to hide deleted files'))
         self.set_warning('free_disk_space', _('This option is very slow.'))
         self.add_option('tmp', _('Temporary files'), _('Delete the temporary files'))
 
@@ -472,8 +441,8 @@ class System(Cleaner):
                 '$LocalAppData\\Microsoft\\Windows\WER\\ReportQueue\\*\\*', \
                 '$programdata\\Microsoft\\Windows\\WER\\ReportArchive\\*\\*', \
                 '$programdata\\Microsoft\\Windows\\WER\\ReportQueue\\*\\*', \
-                '$userprofile\\Local Settings\\Application Data\\Microsoft\\Internet Explorer\\brndlog.bak', \
-                '$userprofile\\Local Settings\\Application Data\\Microsoft\\Internet Explorer\\brndlog.txt', \
+                '$localappdata\\Microsoft\\Internet Explorer\\brndlog.bak', \
+                '$localappdata\\Microsoft\\Internet Explorer\\brndlog.txt', \
                 '$windir\\*.log', \
                 '$windir\\imsins.BAK', \
                 '$windir\\OEWABLog.txt', \
@@ -491,8 +460,11 @@ class System(Cleaner):
                 '$windir\\system32\\TZLog.log', \
                 '$windir\\system32\\config\\systemprofile\\Application Data\\Microsoft\\Internet Explorer\\brndlog.bak', \
                 '$windir\\system32\\config\\systemprofile\\Application Data\\Microsoft\\Internet Explorer\\brndlog.txt', \
+                '$windir\\system32\\LogFiles\\AIT\\AitEventLog.etl.???', \
                 '$windir\\system32\\LogFiles\\Firewall\\pfirewall.log*', \
                 '$windir\\system32\\LogFiles\\Scm\\SCM.EVM*', \
+                '$windir\\system32\\LogFiles\\WMI\\Terminal*.etl', \
+                '$windir\\system32\\LogFiles\\WMI\\RTBackup\EtwRT.*etl', \
                 '$windir\\system32\\wbem\\Logs\\*.lo_', \
                 '$windir\\system32\\wbem\\Logs\\*.log', )
 
@@ -505,6 +477,16 @@ class System(Cleaner):
         if 'linux2' == sys.platform and 'memory' == option_id:
             yield Command.Function(None, Memory.wipe_memory, _('Memory'))
 
+        # memory dump
+        # how to manually create this file
+        # http://www.pctools.com/guides/registry/detail/856/
+        if 'nt' == os.name and 'memory_dump' == option_id:
+            fname = os.path.expandvars('$windir\\memory.dmp')
+            if os.path.exists(fname):
+                files += [ fname ]
+            for fname in glob.iglob(os.path.expandvars('$windir\\Minidump\\*.dmp')):
+                files += [ fname ]
+
         # most recently used documents list
         if 'posix' == os.name and 'recent_documents' == option_id:
             files += [ os.path.expanduser("~/.recently-used") ]
@@ -599,13 +581,13 @@ class System(Cleaner):
         shred_drives = options.get_list('shred_drives')
         if 'free_disk_space' == option_id and shred_drives:
             for pathname in shred_drives:
-                # TRANSLATORS: 'Free' could also be translated 'unallocated.'
+                # TRANSLATORS: 'Free' means 'unallocated.'
                 # %s expands to a path such as C:\ or /tmp/
                 display = _("Overwrite free disk space %s") % pathname
                 def wipe_path_func():
                     for ret in FileUtilities.wipe_path(pathname, idle = True):
                         # Yield control to GTK idle because this process
-                        # is very slow.
+                        # is very slow.  Also display progress.
                         yield ret
                     yield 0
                 yield Command.Function(None, wipe_path_func, display)
@@ -635,6 +617,10 @@ class System(Cleaner):
                 # fixme: enable size preview
                 yield Command.Function(None, emptyrecyclebin, label)
 
+        # Windows Updates
+        if 'nt' == os.name and 'updates' == option_id:
+            for wu in Windows.delete_updates():
+                yield wu
 
 
     def whitelisted(self, pathname):
@@ -658,8 +644,6 @@ class System(Cleaner):
 # initialize "hard coded" (non-CleanerML) backends
 backends = {}
 backends["firefox"] = Firefox()
-if 'posix' == os.name:
-    backends["rpmbuild"] = rpmbuild()
 backends["openofficeorg"] = OpenOfficeOrg()
 backends["system"] = System()
 
@@ -667,19 +651,43 @@ backends["system"] = System()
 def create_simple_cleaner(paths):
     cleaner = Cleaner()
     cleaner.add_option(option_id = 'files', name = '', description = '')
-    cleaner.name = ''
+    cleaner.name = _("System") # shows up in progress bar
+
     import Action
-    import Command
+
     class CustomFileAction(Action.ActionProvider):
         action_key = '__customfileaction'
         def get_commands(self):
             for path in paths:
-                yield Command.Shred(path)
+                if os.path.isdir(path):
+                    for child in children_in_directory(path, True):
+                        yield Command.Shred(child)
+                    yield Command.Shred(path)
+                else:
+                    yield Command.Shred(path)
     provider = CustomFileAction(None)
     cleaner.add_action('files', provider)
     return cleaner
 
 
+def create_wipe_cleaner(path):
+    cleaner = Cleaner()
+    cleaner.add_option(option_id = 'free_disk_space', name = '', description = '')
+    cleaner.name = ''
 
+    # create a temporary cleaner object
+    display = _("Overwrite free disk space %s") % path
+    def wipe_path_func():
+        for ret in FileUtilities.wipe_path(path, idle = True):
+            yield ret
+        yield 0
 
+    import Action
+    class CustomWipeAction(Action.ActionProvider):
+        action_key = '__customwipeaction'
+        def get_commands(self):
+            yield Command.Function(None, wipe_path_func, display)
+    provider = CustomWipeAction(None)
+    cleaner.add_action('free_disk_space', provider)
+    return cleaner
 
