@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -27,10 +27,11 @@ import gettext
 import locale
 import os
 import sys
-import traceback
 
+if 'nt' == os.name:
+    from win32com.shell import shell, shellcon
 
-APP_VERSION = "0.8.0"
+APP_VERSION = "0.8.7"
 APP_NAME = "BleachBit"
 APP_URL = "http://bleachbit.sourceforge.net"
 
@@ -109,7 +110,6 @@ appicon_path = None
 for __icon in __icons:
     if os.path.exists(__icon):
         appicon_path = __icon
-print "debug: appicon_path = '%s'" % (appicon_path, )
 
 
 # locale directory
@@ -132,10 +132,19 @@ launcher_path = '/usr/share/applications/bleachbit.desktop'
 if 'posix' == os.name:
     autostart_path = os.path.expanduser('~/.config/autostart/bleachbit.desktop')
 if 'nt' == os.name:
-    from win32com.shell import shell, shellcon
     autostart_path = os.path.join(shell.SHGetSpecialFolderPath(None, shellcon.CSIDL_STARTUP), 'bleachbit.lnk')
 
 
+###
+### setup environment
+###
+
+# Windows XP doesn't define localappdata, but Windows Vista and 7 do
+if 'nt' == os.name:
+    if None == os.getenv('localappdata'):
+        os.environ['localappdata'] = shell.SHGetSpecialFolderPath(None, shellcon.CSIDL_LOCAL_APPDATA)
+
+
 ###
 ### gettext
 ###
@@ -154,16 +163,24 @@ if 'win32' == sys.platform:
     os.environ['LANG'] = user_locale
 
 try:
+    if not os.path.exists(locale_dir):
+        raise RuntimeError('translations not installed')
     t = gettext.translation('bleachbit', locale_dir)
     _ = t.ugettext
 except:
-    if 'C' != user_locale and 'en' != user_locale[0:2]:
-        traceback.print_exc()
-        print "warning: gettext() failed so translations will be unavailable"
     def _(msg):
-        """Dummy replacement for gettext"""
+        """Dummy replacement for ugettext"""
         return msg
 
+try:
+    ungettext = t.ungettext
+except:
+    def ungettext(singular, plural, n):
+        """Dummy replacement for Unicode, plural gettext"""
+        if 1 == n:
+            return singular
+        return plural
+
 
 ###
 ### pgettext
