@@ -2,7 +2,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -49,19 +49,6 @@ if 'nt' == os.name:
 
 
 
-def open_url(url):
-    """Open an HTTP URL"""
-    print "debug: on_url('%s')" % (url,)
-    try:
-        import gnomevfs
-        gnomevfs.url_show(url)
-        return
-    except:
-        import webbrowser
-        webbrowser.open(url)
-
-
-
 def threaded(func):
     """Decoration to create a threaded function"""
     def wrapper(*args):
@@ -137,10 +124,13 @@ class TreeDisplayModel:
     """Displays the info model in a view"""
 
 
-    def make_view(self, model, parent):
+    def make_view(self, model, parent, context_menu_event):
         """Create and return a TreeView object"""
         self.view = gtk.TreeView(model)
 
+        # listen for right click (context menu)
+        self.view.connect("button_press_event", context_menu_event)
+
         # first column
         self.renderer0 = gtk.CellRendererText()
         self.column0 = gtk.TreeViewColumn(_("Name"), self.renderer0, text=0)
@@ -180,9 +170,16 @@ class TreeDisplayModel:
         if cleaner_id and value:
             # when toggling an option, present any warnings
             warning = backends[cleaner_id].get_warning(option_id)
+            # TRANSLATORS: %(cleaner) may be Firefox, System, etc.
+            # %(option) may be cache, logs, cookies, etc.
+            # %(warning) may be 'This option is really slow'
+            msg = _("Warning regarding %(cleaner)s - %(option)s:\n\n%(warning)s") % \
+                { 'cleaner' : model[parent][0], \
+                  'option'  : model[path][0], \
+                  'warning' : warning }
             if warning:
                 resp = GuiBasic.message_dialog(parent_window, \
-                    warning, \
+                    msg, \
                     gtk.MESSAGE_WARNING, gtk.BUTTONS_OK_CANCEL)
                 if gtk.RESPONSE_OK != resp:
                     # user cancelled, so don't toggle option
@@ -225,6 +222,8 @@ class GUI:
     <menubar name="MenuBar">
         <menu action="File">
             <menuitem action="ShredFiles"/>
+            <menuitem action="ShredFolders"/>
+            <menuitem action="WipeFreeSpace"/>
             <menuitem action="ShredQuit"/>
             <menuitem action="Quit"/>
         </menu>
@@ -391,10 +390,11 @@ class GUI:
 
     def about(self, __event):
         """Create and show the about dialog"""
-        gtk.about_dialog_set_url_hook(lambda dialog, link: open_url(link))
+        gtk.about_dialog_set_url_hook(lambda dialog, \
+            link: GuiBasic.open_url(link, self.window, False))
         dialog = gtk.AboutDialog()
         dialog.set_comments(_("Program to clean unnecessary files"))
-        dialog.set_copyright("Copyright (C) 2010 Andrew Ziem")
+        dialog.set_copyright("Copyright (C) 2011 Andrew Ziem")
         try:
             dialog.set_license(open(license_filename).read())
         except:
@@ -448,7 +448,7 @@ class GUI:
         self.tree_store = TreeInfoModel()
         display = TreeDisplayModel()
         mdl = self.tree_store.get_model()
-        self.view = display.make_view(mdl, self.window)
+        self.view = display.make_view(mdl, self.window, self.context_menu_event)
         self.view.get_selection().connect("changed", self.on_selection_changed)
         scrolled_window.add(self.view)
         return scrolled_window
@@ -466,12 +466,35 @@ class GUI:
         self.view.expand_all()
 
 
+    def cb_run_option(self, widget, really_delete, cleaner_id, option_id):
+        """Callback from context menu to delete/preview a single option"""
+        operations = { cleaner_id : [ option_id ] }
+
+        # preview
+        if not really_delete:
+            self.preview_or_run_operations(False, operations)
+            return
+
+        # delete
+        if GuiBasic.delete_confirmation_dialog(self.window, mention_preview = False):
+            self.preview_or_run_operations(True, operations)
+            return
+
+
     def cb_shred_file(self, action):
-        """Callback for shredding a file"""
+        """Callback for shredding a file or folder"""
 
         # get list of files
-        paths = GuiBasic.browse_files(self.window, \
-            _("Choose files to shred"))
+        if 'ShredFiles' == action.get_name():
+            paths = GuiBasic.browse_files(self.window, \
+                _("Choose files to shred"))
+        elif 'ShredFolders' == action.get_name():
+            paths = GuiBasic.browse_folder(self.window, \
+                _("Choose folder to shred"),
+                multiple = True,
+                stock_button = gtk.STOCK_DELETE)
+        else:
+            raise RuntimeError("Unexpected kind in cb_shred_file")
 
         if not paths:
             return
@@ -485,14 +508,9 @@ class GUI:
 
         if GuiBasic.delete_confirmation_dialog(self.window, mention_preview = False):
             # delete
-            options.set('shred', True, commit = False)
             self.preview_or_run_operations(True, operations)
-            options.restore()
             return
 
-        # clean up temporary cleaner
-        del backends['_gui']
-
 
     def cb_shred_quit(self, action):
         """Shred settings (for privacy reasons) and quit"""
@@ -523,6 +541,59 @@ class GUI:
         gtk.main_quit()
 
 
+    def cb_wipe_free_space(self, action):
+        """callback to wipe free space in arbitrary folder"""
+        path = GuiBasic.browse_folder(self.window, \
+            _("Choose a folder"), \
+            multiple = False, stock_button = gtk.STOCK_OK)
+        if not path:
+            # user cancelled
+            return
+
+        backends['_gui'] = Cleaner.create_wipe_cleaner(path)
+
+        # execute
+        operations = { '_gui' : [ 'free_disk_space' ] }
+        self.preview_or_run_operations(True, operations)
+
+
+    def context_menu_event(self, treeview, event):
+        """When user right clicks on the tree view"""
+        if event.button != 3:
+            return False
+        pathinfo = treeview.get_path_at_pos(int(event.x), int(event.y))
+        if None == pathinfo:
+            return False
+        path, col, cellx, celly = pathinfo
+        treeview.grab_focus()
+        treeview.set_cursor(path, col, 0)
+        # context menu applies only to children, not parents
+        if 2 != len(path):
+            return False
+        # find the seleted option
+        model = treeview.get_model()
+        option_id = model[path][2]
+        option_name = model[path][0]
+        cleaner_id = model[path[0]][2]
+        cleaner_name = model[path[0]][0]
+        # make a menu
+        menu = gtk.Menu()
+        preview_item = gtk.MenuItem(_("Preview"))
+        preview_item.connect('activate', self.cb_run_option, \
+            False, cleaner_id, option_id)
+        menu.append(preview_item)
+        delete_item = gtk.MenuItem(_("Delete"))
+        delete_item.connect('activate', self.cb_run_option, \
+            True, cleaner_id, option_id)
+        menu.append(delete_item)
+
+        # show the context menu
+        menu.attach_to_widget(treeview, menu.destroy)
+        menu.show_all()
+        menu.popup(None, None, None, event.button, event.time)
+        return True
+
+
     def update_progress_bar(self, status):
         """Callback to update the progress bar with number or text"""
         if type(status) is float:
@@ -557,14 +628,18 @@ class GUI:
 
         # Create actions
         entries = (
-                    ('ShredFiles', gtk.STOCK_DELETE, _('_Shred Files'), None, None, self.cb_shred_file),
+                    ('ShredFiles', None, _('_Shred Files'), None, None, self.cb_shred_file),
+                    ('ShredFolders', None, _('Sh_red Folders'), None, None, self.cb_shred_file),
+                    ('WipeFreeSpace', None, _('_Wipe Free Space'), None, None, self.cb_wipe_free_space),
                     ('ShredQuit', None, _('S_hred Settings and Quit'), None, None, self.cb_shred_quit),
                     ('Quit', gtk.STOCK_QUIT, _('_Quit'), None, None, lambda *dummy: gtk.main_quit()),
                     ('File', None, _('_File')),
                     ('Preferences', gtk.STOCK_PREFERENCES, _("Preferences"), None, None, self.cb_preferences_dialog),
                     ('Edit', None, _("_Edit")),
-                    ('HelpContents', gtk.STOCK_HELP, _('Help Contents'), 'F1', None, lambda link: open_url(help_contents_url)),
-                    ('ReleaseNotes', gtk.STOCK_INFO, _('_Release Notes'), None, None, lambda link: open_url(release_notes_url)),
+                    ('HelpContents', gtk.STOCK_HELP, _('Help Contents'), 'F1', None, \
+                        lambda link: GuiBasic.open_url(help_contents_url, self.window)),
+                    ('ReleaseNotes', gtk.STOCK_INFO, _('_Release Notes'), None, None, \
+                        lambda link: GuiBasic.open_url(release_notes_url, self.window)),
                     ('SystemInformation', None, _('_System Information'), None, None, lambda foo: self.diagnostic_dialog(self.window)),
                     ('About', gtk.STOCK_ABOUT, _('_About'), None, None, self.about),
                     ('Help', None, _("_Help")))
@@ -614,8 +689,6 @@ class GUI:
     def create_window(self):
         """Create the main application window"""
 
-        print 'info: GTK version %s' % '.'.join([str(x) for x in gtk.gtk_version])
-
         self.window = gtk.Window()
         self.window.connect('destroy', lambda w: gtk.main_quit())
 
@@ -682,39 +755,17 @@ class GUI:
         self.progressbar.hide()
         return
 
-    def enable_online_update(self, url):
-        """Create a button to launch browser to initiate software update"""
-        icon = gtk.Image()
-        icon.set_from_stock(gtk.STOCK_NETWORK, gtk.ICON_SIZE_LARGE_TOOLBAR)
-        update_button = gtk.ToolButton(icon_widget = icon, label = _p('button', 'Update BleachBit'))
-        update_button.show_all()
-        update_button.connect("clicked", lambda toolbutton, url: open_url(url), url)
-        update_button.set_is_important(True)
-        self.toolbar.insert(update_button, -1)
-        msg = _("BleachBit update is available")
-        try:
-            import pynotify
-        except:
-            print "debug: pynotify not available"
-            self.append_text(msg)
-        else:
-            if pynotify.init(APP_NAME):
-                notify = pynotify.Notification(msg, _("Click 'Update BleachBit' for more information"))
-                # this doesn't align the notification properly
-                #n.attach_to_widget(update_button)
-                notify.attach_to_widget(self.toolbar)
-                notify.show()
-
 
     @threaded
     def check_online_updates(self):
         """Check for software updates in background"""
         import Update
         try:
-            update = Update.Update()
-            if update.is_update_available():
-                gobject.idle_add(self.enable_online_update, update.get_update_info_url())
+            updates = Update.check_updates(options.get('check_beta'))
+            if updates:
+                gobject.idle_add(lambda: Update.update_dialog(self.window, updates))
         except:
+            traceback.print_exc()
             self.append_text(_("Error when checking for updates: ") + str(sys.exc_info()[1]), 'error')
 
 
@@ -726,6 +777,9 @@ class GUI:
         RecognizeCleanerML.RecognizeCleanerML()
         import CleanerML
         CleanerML.load_cleaners()
+        if 'nt' == os.name:
+            import Winapp
+            Winapp.load_cleaners()
         self.create_window()
         gobject.threads_init()
         if options.get("first_start") and 'posix' == os.name:
@@ -746,7 +800,6 @@ class GUI:
                 self.append_text(_("Error loading the SQLite module: the antivirus software may be blocking it."), 'error')
 
 
-
 if __name__ == '__main__':
     gui = GUI()
     gtk.main()
