@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -35,33 +35,39 @@ from Common import _
 
 
 
-def browse_folder(parent, title):
+def browse_folder(parent, title, multiple, stock_button):
     """Ask the user to select a folder.  Return the full path or None."""
 
     if 'nt' == os.name:
-        return Windows.browse_folder(parent.window.handle, title)
+        ret = Windows.browse_folder(parent.window.handle, title)
+        return [ret] if multiple else ret
 
     # fall back to GTK+
     chooser = gtk.FileChooserDialog( parent = parent, \
         title = title,
         buttons = (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, \
-        gtk.STOCK_ADD, gtk.RESPONSE_ACCEPT), \
+            stock_button, gtk.RESPONSE_OK), \
         action = gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER)
+    chooser.set_select_multiple(multiple)
     chooser.set_current_folder(os.path.expanduser('~'))
     resp = chooser.run()
-    pathname = chooser.get_filename()
+    if multiple:
+        ret = chooser.get_filenames()
+    else:
+        ret = chooser.get_filename()
     chooser.hide()
     chooser.destroy()
-    if gtk.RESPONSE_ACCEPT == resp:
-        return pathname
-    # user cancelled
-    return None
+    if gtk.RESPONSE_OK != resp:
+        # user cancelled
+        return None
+    return ret
 
 
 def browse_file(parent, title):
     """Prompt user to select a single file"""
 
-    # FIXME: add native Windows dialog
+    if 'nt' == os.name:
+        return Windows.browse_file(parent.window.handle, title)
 
     chooser = gtk.FileChooserDialog(title = title,
         parent = parent,
@@ -132,12 +138,12 @@ def delete_confirmation_dialog(parent, mention_preview):
     return ret == gtk.RESPONSE_ACCEPT
 
 
-def message_dialog(parent, msg, type = gtk.MESSAGE_ERROR, buttons = gtk.BUTTONS_OK):
+def message_dialog(parent, msg, mtype = gtk.MESSAGE_ERROR, buttons = gtk.BUTTONS_OK):
     """Convenience wrapper for gtk.MessageDialog"""
 
     dialog = gtk.MessageDialog(parent, \
         gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT, \
-        type, \
+        mtype, \
         buttons, \
         msg)
     resp = dialog.run()
@@ -145,3 +151,34 @@ def message_dialog(parent, msg, type = gtk.MESSAGE_ERROR, buttons = gtk.BUTTONS_
 
     return resp
 
+
+def open_url(url, parent_window = None, prompt = True):
+    """Open an HTTP URL.  Try to run as non-root."""
+    # drop privileges so the web browser is running as a normal process
+    if 'posix' == os.name and 0 == os.getuid():
+        msg = _("Because you are running as root, please manually open this link in a web browser:\n%s") % url
+        message_dialog(None, msg, gtk.MESSAGE_INFO)
+        return
+    if prompt:
+        # find hostname
+        import re
+        ret = re.search('^http(s)?://([a-z\.]+)', url)
+        if None == ret:
+            host = url
+        else:
+            host = ret.group(2)
+        # TRANSLATORS: %s expands to bleachbit.sourceforge.net or similar
+        msg = _("Open web browser to %s?") % host
+        resp = message_dialog(parent_window, msg, \
+            gtk.MESSAGE_QUESTION, gtk.BUTTONS_OK_CANCEL)
+        if gtk.RESPONSE_OK != resp:
+            return
+    # open web browser
+    try:
+        import gnomevfs
+        gnomevfs.url_show(url)
+        return
+    except:
+        import webbrowser
+        webbrowser.open(url)
+
