@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -31,7 +31,6 @@ import os
 import re
 import subprocess
 import sys
-import time
 import traceback
 
 import FileUtilities
@@ -64,7 +63,8 @@ def disable_swap_linux():
         if '' == line:
             continue
         # English is 'swapoff on /dev/sda5' but German is 'swapoff für ...'
-        ret = re.search('^swapoff .* (/dev/([hs]d[a-z][0-9]+|mapper/swap))$', line)
+        # This matches swap devices and swap files
+        ret = re.search('^swapoff .* (/[\w/\.]+)$', line)
         if None == ret:
             raise RuntimeError("Unexpected output:\nargs='%(args)s'\nstdout='%(stdout)s'\nstderr='%(stderr)s'" \
                 % { 'args' : str(args), 'stdout' : stdout, 'stderr' : stderr } )
@@ -111,15 +111,15 @@ def fill_memory_linux():
             return
         megabytes = allocbytes / (1024**2)
         print "info: allocating %.2f MB (%d B) memory" % (megabytes, allocbytes)
-        buffer = libc.malloc(allocbytes)
-        if 0 == buffer:
-            print 'debug: malloc() returned', buffer
+        mbuffer = libc.malloc(allocbytes)
+        if 0 == mbuffer:
+            print 'debug: malloc() returned', mbuffer
             return
         print "debug: wiping %.2f MB I just allocated" % megabytes
-        libc.memset(buffer, 0x00, allocbytes)
+        libc.memset(mbuffer, 0x00, allocbytes)
         fill_helper()
         print "debug: freeing %.2f MB memory" % megabytes
-        libc.free(buffer)
+        libc.free(mbuffer)
         report_free()
     fill_helper()
 
@@ -210,8 +210,9 @@ def physical_free():
 
 def report_free():
     """Report free memory"""
-    bytes = physical_free()
-    print "debug: physical free: %d B (%d MB)" % (bytes, bytes/1024**2)
+    bytes_free = physical_free()
+    print "debug: physical free: %d B (%d MB)" % \
+        (bytes_free, bytes_free / 1024**2)
 
 
 def wipe_swap_linux(devices, proc_swaps):
