@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -31,7 +31,7 @@ import Common
 import General
 
 
-boolean_keys = ('auto_hide', 'auto_start', 'check_online_updates', 'first_start', 'shred')
+boolean_keys = ('auto_hide', 'auto_start', 'check_beta', 'check_online_updates', 'first_start', 'shred')
 
 
 
@@ -40,6 +40,7 @@ class Options:
 
 
     def __init__(self):
+        self.config = ConfigParser.SafeConfigParser()
         self.restore()
 
 
@@ -105,17 +106,17 @@ class Options:
         section = "whitelist/paths"
         if not self.config.has_section(section):
             return []
-        options = []
+        myoptions = []
         for option in sorted(self.config.options(section)):
             pos = option.find('_')
             if -1 == pos:
                 continue
-            options.append(option[0:pos])
+            myoptions.append(option[0:pos])
         values = []
-        for option in set(options):
-            type = self.config.get(section, option + '_type')
-            path = self.config.get(section, option + '_path')
-            values.append( ( type, path ) )
+        for option in set(myoptions):
+            wl_type = self.config.get(section, option + '_type')
+            wl_path = self.config.get(section, option + '_path')
+            values.append( ( wl_type, wl_path ) )
         return values
 
 
@@ -131,7 +132,6 @@ class Options:
 
     def restore(self):
         """Restore saved options from disk"""
-        self.config = ConfigParser.SafeConfigParser()
         try:
             self.config.read(Common.options_file)
         except:
@@ -151,6 +151,7 @@ class Options:
         # set defaults
         self.__set_default("auto_hide", True)
         self.__set_default("auto_start", False)
+        self.__set_default("check_beta", False)
         self.__set_default("check_online_updates", True)
         self.__set_default("shred", False)
 
