@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -58,21 +58,9 @@ def cleaner_change_dialog(changes, parent):
 
     def toggled(cell, path, model):
         """Callback for clicking the checkbox"""
-#        i = model.get_iter(path)
-#        model[i][0] = not model[i][0]
         __iter = model.get_iter_from_string(path)
         value = not model.get_value(__iter, 0)
         model.set(__iter, 0, value)
-#        import pdb
-#        pdb.set_trace()
-
-    def preserve_toggled_cb(cell, path, liststore):
-            """Callback for toggling the 'preserve' column"""
-            __iter = liststore.get_iter_from_string(path)
-            value = not liststore.get_value(__iter, 0)
-            liststore.set(__iter, 0, value)
-            langid = liststore[path][1]
-            options.set_language(langid, value)
 
 
     import pygtk
@@ -164,7 +152,7 @@ class RecognizeCleanerML:
         self.parent_window = parent_window
         try:
             self.salt = options.get('hashsalt')
-        except ConfigParser.NoOptionError, e:
+        except ConfigParser.NoOptionError:
             self.salt = hashdigest(str(random.random()))
             options.set('hashsalt', self.salt)
         self.__scan()
@@ -176,7 +164,7 @@ class RecognizeCleanerML:
         new_hash = hashdigest(self.salt + body)
         try:
             known_hash = options.get(pathname, 'hashpath')
-        except ConfigParser.NoOptionError, e:
+        except ConfigParser.NoOptionError:
             return (NEW, new_hash)
         if new_hash == known_hash:
             return (KNOWN, new_hash)
@@ -188,17 +176,17 @@ class RecognizeCleanerML:
         changes = []
         for pathname in sorted(list_cleanerml_files(local_only = True)):
             pathname = os.path.abspath(pathname)
-            (status, hash) = self.__recognized(pathname)
+            (status, myhash) = self.__recognized(pathname)
             if NEW == status or CHANGED == status:
-                changes.append([ pathname, status, hash ])
+                changes.append([ pathname, status, myhash ])
         if len(changes) > 0:
             cleaner_change_dialog(changes, self.parent_window)
             for change in changes:
                 pathname = change[0]
-                hash = change[2]
+                myhash = change[2]
                 print "info: remembering CleanerML file '%s'" % pathname
                 if os.path.exists(pathname):
-                    options.set(pathname, hash, 'hashpath')
+                    options.set(pathname, myhash, 'hashpath')
 
 
 
