@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -28,10 +28,40 @@ from Options import options
 import FileUtilities
 
 
+def __shred_sqlite_char_columns(table, cols, where = ""):
+    """Create an SQL command to shred character columns"""
+    cmd = ""
+    if cols and options.get('shred'):
+        cmd += "update %s set %s %s;" % \
+            (table, ",".join(["%s = randomblob(length(%s))" % (col, col)  for col in cols]), where)
+        cmd += "update %s set %s %s;" % \
+            (table, ",".join(["%s = zeroblob(length(%s))" % (col, col)  for col in cols]), where)
+    cmd += "delete from %s %s;" % (table, where)
+    return cmd
+
+
+def delete_chrome_autofill(path):
+    """Delete autofill table in Chromium/Google Chrome 'Web Data' database"""
+    cols = ('name', 'value', 'value_lower')
+    cmds = __shred_sqlite_char_columns('autofill', cols)
+    cmds += __shred_sqlite_char_columns('autofill_dates', () )
+    FileUtilities.execute_sqlite3(path, cmds)
+
+
+def delete_chrome_keywords(path):
+    """Delete keywords table in Chromium/Google Chrome 'Web Data' database"""
+    cols = ('short_name', 'keyword', 'favicon_url', 'originating_url', 'suggest_url')
+    where = "where not date_created = 0"
+    cmds = __shred_sqlite_char_columns('keywords', cols, where)
+    cmds += "update keywords set usage_count = 0;"
+    FileUtilities.execute_sqlite3(path, cmds)
+
 
 def delete_mozilla_url_history(path):
     """Delete URL history in Mozilla places.sqlite (Firefox 3 and family)"""
 
+    cmds = ""
+
     # delete the URLs in moz_places
     places_suffix = "where id in (select " \
         "moz_places.id from moz_places " \
@@ -40,23 +70,8 @@ def delete_mozilla_url_history(path):
         "where moz_inputhistory.input is null " \
         "and moz_bookmarks.id is null); "
 
-    cmds = ""
-
-    if options.get('shred'):
-        shred_places_cmd = "update moz_places " \
-            "set url = randomblob(length(url)), " \
-            "rev_host = randomblob(length(rev_host)), " \
-            "title = randomblob(length(title))" + places_suffix
-        cmds += shred_places_cmd
-        shred_places_cmd = "update moz_places " \
-            "set url = zeroblob(length(url)), " \
-            "rev_host = zeroblob(length(rev_host)), " \
-            "title = zeroblob(length(title))" + places_suffix
-        cmds += shred_places_cmd
-
-
-    delete_places_cmd = "delete from moz_places " + places_suffix
-    cmds += delete_places_cmd
+    cols = ('url', 'rev_host', 'title')
+    cmds += __shred_sqlite_char_columns('moz_places', cols, places_suffix)
 
     # delete any orphaned annotations in moz_annos
     annos_suffix =  "where id in (select moz_annos.id " \
@@ -65,42 +80,18 @@ def delete_mozilla_url_history(path):
         "on moz_annos.place_id = moz_places.id " \
         "where moz_places.id is null); "
 
-    if options.get('shred'):
-        shred_annos_cmd = "update moz_annos " \
-            "set content = randomblob(length(content)) " \
-            + annos_suffix
-        cmds += shred_annos_cmd
-        shred_annos_cmd = "update moz_annos " \
-            "set content = zeroblob(length(content)) " \
-            + annos_suffix
-        cmds += shred_annos_cmd
-
-    delete_annos_cmd = "delete from moz_annos " + annos_suffix
-    cmds += delete_annos_cmd
+    cmds += __shred_sqlite_char_columns('moz_annos', ('content', ), annos_suffix)
 
     # delete any orphaned favicons
     fav_suffix = "where id not in (select favicon_id " \
-        "from moz_places ); "
+        "from moz_places where favicon_id is not null ); "
 
-    if options.get('shred'):
-        shred_fav_cmd = "update moz_favicons " \
-            "set url = randomblob(length(url)), " \
-            "data = randomblob(length(data)) " \
-            +  fav_suffix
-        cmds += shred_fav_cmd
-        shred_fav_cmd = "update moz_favicons " \
-            "set url = zeroblob(length(url)), " \
-            "data = zeroblob(length(data)) " \
-            +  fav_suffix
-        cmds += shred_fav_cmd
-
-
-    delete_fav_cmd = "delete from moz_favicons " + fav_suffix
-    cmds += delete_fav_cmd
+    cols = ('url', 'data')
+    cmds += __shred_sqlite_char_columns('moz_favicons', cols, fav_suffix)
 
     # delete any orphaned history visits
     cmds += "delete from moz_historyvisits where place_id not " \
-        "in (select id from moz_places); "
+        "in (select id from moz_places where id is not null); "
 
     # execute the commands
     FileUtilities.execute_sqlite3(path, cmds)
@@ -108,7 +99,7 @@ def delete_mozilla_url_history(path):
 
 
 def delete_ooo_history(path):
-    """Erase the Openoffice.org MRU in Common.xcu"""
+    """Erase the OpenOffice.org MRU in Common.xcu"""
     import xml.dom.minidom
     dom1 = xml.dom.minidom.parse(path)
     for node in dom1.getElementsByTagName("node"):
