@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -30,11 +30,9 @@ import os
 import re
 import shlex
 import subprocess
-import sys
 import ConfigParser
 
-from Common import _
-import Common
+from Common import _, autostart_path, launcher_path
 import FileUtilities
 import General
 
@@ -51,23 +49,11 @@ except:
         gnomevfs = gnome.vfs
 
 
-def free_space(pathname):
-    """Return free space in bytes"""
-    args = ['df', '-B', '1', pathname]
-    (rc, stdout, stderr) = General.run_external(args)
-    if 0 != rc:
-        return None
-    line = stdout.split('\n')[1]
-    match = re.search("^[/a-z0-9]+\s+[0-9]+\s+[0-9]+([0-9]+)", line)
-    if not match:
-        return None
-    return int(match.groups(0)[0])
-
 
 def guess_overwrite_paths():
     """Guess which partitions to overwrite (to hide deleted files)"""
     home = os.path.expanduser("~")
-    if free_space(home) == free_space('/tmp/'):
+    if FileUtilities.free_space(home) == FileUtilities.free_space('/tmp/'):
         return [ home ]
     else:
         return [ home, '/tmp' ]
@@ -112,6 +98,7 @@ class Locales:
         'es' : 'Español', \
         'fi' : 'suomen kieli', \
         'fr' : 'Français', \
+        'fo' : 'føroyskt', \
         'hi' : 'हिन्दी', \
         'hr' : 'Hrvatski', \
         'hu' : 'Magyar', \
@@ -151,11 +138,14 @@ class Locales:
                 '/usr/share/gnucash/accounts',
                 '/usr/share/kde4/apps/ksgmltools2/customization',
                 '/usr/share/locale/',
-                '/usr/share/speedcrunch/books/' ] 
+                '/usr/share/speedcrunch/books/',
+                '/usr/share/vim/vim72/' # Ubuntu 10.10
+                ]
 
     __ignore = ['all_languages', 'C', 'l10n', 'locale.alias', 'default']
 
     ooosharedirs = [ '/usr/lib/openoffice/share/', # Ubuntu 8
+        '/usr/lib/openoffice/basis3.2/share/', # Ubuntu 10.10
         '/usr/lib/openoffice.org/basis3.0/share/', # Fedora 10
         '/opt/ooo-dev/basis3.0/share', # Sun development snapshot
         '/opt/openoffice.org/basis3.0/share/' ] # Sun
@@ -280,10 +270,14 @@ class Locales:
         # /usr/share/cups/doc-root/es/images/button-add-printer.gif
         lps += ( ('/usr/share/cups/doc-root/', dir_filter) , )
 
-        # Evolution
+        # evolution
         # /usr/share/evolution/2.22/help/quickref/es/quickref.pdf
         lps += ( ('/usr/share/evolution/*/help/quickref/', dir_filter) , )
 
+        # Evolution, Ubuntu 10.10
+        # /usr/share/evolution/2.30/default/es/mail
+        lps += ( ('/usr/share/evolution/*.*/default/', dir_filter) , )
+
         # foomatic
         dir_filter = lambda d: 2 != len(d)
         lps += ( ('/usr/share/foomatic/db/source/PPD/Kyocera/', dir_filter) , )
@@ -306,6 +300,8 @@ class Locales:
 
         # /usr/share/i18n/locales/es_ES@euro
         globexs += ( ('/usr/share/i18n/locales/??_*', 'locales/([a-z]{2}_[A-Z]{2})'), )
+        # /usr/share/aptitude/aptitude-defaults.es
+        globexs += ( ('/usr/share/aptitude/aptitude-defaults*', '-defaults.([a-z]{2})'), )
         # /usr/share/ppd/splix/samsung/ml1740fr.ppd
         globexs += ( ('/usr/share/ppd/splix/*/*fr.ppd', '(fr).ppd$' ), )
         # /usr/share/espeak-data/es_dict
@@ -542,22 +538,22 @@ def start_with_computer(enabled):
     """If enabled, create shortcut to start application with computer.
     If disabled, then delete the shortcut."""
     if not enabled:
-        if os.path.lexists(Common.autostart_path):
-            FileUtilities.delete(Common.autostart_path)
+        if os.path.lexists(autostart_path):
+            FileUtilities.delete(autostart_path)
         return
-    if os.path.lexists(Common.autostart_path):
+    if os.path.lexists(autostart_path):
         return
     import shutil
-    General.makedirs(os.path.dirname(Common.autostart_path))
-    shutil.copy(Common.launcher_path, Common.autostart_path)
-    os.chmod(Common.autostart_path, 0755)
+    General.makedirs(os.path.dirname(autostart_path))
+    shutil.copy(launcher_path, autostart_path)
+    os.chmod(autostart_path, 0755)
     if General.sudo_mode():
-        General.chownself(Common.autostart_path)
+        General.chownself(autostart_path)
 
 
 def start_with_computer_check():
     """Return boolean whether BleachBit will start with the computer"""
-    return os.path.lexists(Common.autostart_path)
+    return os.path.lexists(autostart_path)
 
 
 def wine_to_linux_path(wineprefix, windows_pathname):
@@ -586,6 +582,10 @@ def yum_clean():
         if len(line) > 2:
             non_blank_line = line
         if -1 != line.find('You need to be root'):
+            # Seen before Fedora 13
+            raise RuntimeError(line)
+        if -1 != line.find('Cannot remove rpmdb file'):
+            # Since first in Fedora 13
             raise RuntimeError(line)
         if -1 != line.find('Another app is currently holding'):
             print "debug: yum: '%s'" % line
