@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -40,8 +40,10 @@ These are the terms:
 
 
 
+import glob
 import os
 import platform
+import re
 import sys
 import traceback
 
@@ -61,10 +63,27 @@ if 'win32' == sys.platform:
     psapi = windll.psapi
     kernel = windll.kernel32
 
-import FileUtilities
+import Command
 import Common
+import FileUtilities
 import General
 
+def browse_file(hwnd, title):
+    """Ask the user to select a single file.  Return full path"""
+    try:
+        ret = win32gui.GetOpenFileNameW(None, \
+            Flags = win32con.OFN_EXPLORER \
+                | win32con.OFN_FILEMUSTEXIST \
+                | win32con.OFN_HIDEREADONLY, \
+            Title = title)
+    except pywintypes.error, e:
+        if 0 == e.winerror:
+            print 'debug: browse_file(): user cancelled'
+        else:
+            traceback.print_exc()
+        return None
+    return ret[0]
+
 
 def browse_files(hwnd, title):
     """Ask the user to select files.  Return full paths"""
@@ -94,8 +113,6 @@ def browse_files(hwnd, title):
 
 def browse_folder(hwnd, title):
     """Ask the user to select a folder.  Return full path."""
-    from win32com.shell import shell
-
     pidl = shell.SHBrowseForFolder(hwnd, None, title)[0]
     if None == pidl:
         # user cancelled
@@ -168,6 +185,49 @@ def delete_registry_key(parent_key, really_delete):
     return True
 
 
+def delete_updates():
+    """Returns commands for deleting Windows Updates files"""
+    windir = os.path.expandvars('$windir')
+    dirs = glob.glob(os.path.join(windir,'$NtUninstallKB*'))
+    dirs += [ os.path.expandvars('$windir\\SoftwareDistribution\\Download') ]
+    dirs += [ os.path.expandvars('$windir\\ie7updates') ]
+    dirs += [ os.path.expandvars('$windir\\ie8updates') ]
+    if not dirs:
+        # if nothing to delete, then also do not restart service
+        return
+    args = ['net', 'stop', 'wuauserv']
+    def wu_service():
+        General.run_external(args)
+        return 0
+    yield Command.Function(None, wu_service, " ".join(args))
+
+    for path1 in dirs:
+        for path2 in FileUtilities.children_in_directory(path1, True):
+            yield Command.Delete(path2)
+        if os.path.exists(path1):
+            yield Command.Delete(path1)
+
+    args = ['net', 'start', 'wuauserv']
+    yield Command.Function(None, wu_service, " ".join(args))
+
+
+def detect_registry_key(parent_key):
+    """Detect whether registry key exists"""
+    parent_key = str(parent_key) # Unicode to byte string
+    (hive, parent_sub_key) = split_registry_key(parent_key)
+    hkey = None
+    try:
+        hkey = _winreg.OpenKey(hive, parent_sub_key)
+    except WindowsError, e:
+        if e.winerror == 2:
+            # 2 = 'file not found' happens when key does not exist
+            return False
+    if not hkey:
+        # key not found
+        return False
+    return True
+
+
 def elevate_privileges():
     """On Windows Vista and later, try to get administrator
     privileges.  If successful, return True (so original process
@@ -267,7 +327,10 @@ def enumerate_processes_win32():
             psapi.EnumProcessModules(hProcess, byref(hModule), sizeof(hModule), byref(count))
             psapi.GetModuleBaseNameA(hProcess, hModule.value, modname, sizeof(modname))
             clean_modname = "".join([ i for i in modname if i != '\x00']).lower()
-            if len(clean_modname) > 0:
+            if len(clean_modname) > 0 and '?' != clean_modname:
+                # Filter out non-ASCII characters which we don't need
+                # and which may cause warnings.
+                clean_modname2 = re.sub('[^a-z\.]', '_', clean_modname)
                 modnames.append(clean_modname)
 
             # Clean up
@@ -320,7 +383,9 @@ def split_registry_key(full_key):
     Used internally."""
     assert ( len (full_key) > 6 )
     hive_str = full_key[0:4]
-    hive_map = { 'HKCU' : _winreg.HKEY_CURRENT_USER,
+    hive_map = { 
+        'HKCR' : _winreg.HKEY_CLASSES_ROOT,
+        'HKCU' : _winreg.HKEY_CURRENT_USER,
         'HKLM' : _winreg.HKEY_LOCAL_MACHINE }
     if hive_str not in hive_map:
         raise RuntimeError("Invalid Windows registry hive '%s'" % hive_str)
