@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -39,7 +39,9 @@ import TestGeneral
 import TestMemory
 import TestOptions
 import TestRecognizeCleanerML
+import TestSpecial
 import TestUpdate
+import TestWinapp
 import TestWorker
 
 
@@ -54,7 +56,9 @@ suites = [ TestAction.suite(),
            TestMemory.suite(),
            TestOptions.suite(),
            TestRecognizeCleanerML.suite(),
+           TestSpecial.suite(),
            TestUpdate.suite(),
+           TestWinapp.suite(),
            TestWorker.suite() ]
 
 if 'posix' == os.name:
