@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -25,15 +25,94 @@ Test case for module FileUtilities
 """
 
 
-import datetime
 import locale
+import subprocess
 import sys
 import tempfile
+import time
 import unittest
 
 sys.path.append('.')
 from bleachbit.FileUtilities import *
+from bleachbit.Options import options
 
+try:
+    import json
+except:
+    import simplejson as json
+
+
+def test_ini_helper(self, execute):
+    """Used to test .ini cleaning in TestAction and in TestFileUtilities"""
+
+    # create test file
+    (fd, filename) = tempfile.mkstemp()
+    os.write(fd, '#Test\n')
+    os.write(fd, '[RecentsMRL]\n')
+    os.write(fd, 'list=C:\\Users\\me\\Videos\\movie.mpg,C:\\Users\\me\\movie2.mpg\n\n')
+    os.close(fd)
+    self.assert_(os.path.exists(filename))
+    size = os.path.getsize(filename)
+    self.assertEqual(77, size)
+
+    # section does not exist
+    execute(filename, 'Recents', None)
+    self.assertEqual(77, os.path.getsize(filename))
+
+    # parameter does not exist
+    execute(filename, 'RecentsMRL', 'files')
+    self.assertEqual(77, os.path.getsize(filename))
+
+    # parameter does exist
+    execute(filename, 'RecentsMRL', 'list')
+    self.assertEqual(14, os.path.getsize(filename))
+
+    # section does exist
+    execute(filename, 'RecentsMRL', None)
+    self.assertEqual(0, os.path.getsize(filename))
+
+    # clean up
+    delete(filename)
+    self.assert_(not os.path.exists(filename))
+
+
+def test_json_helper(self, execute):
+    """Used to test JSON cleaning in TestAction and in TestFileUtilities"""
+
+    def load_js(js_fn):
+        with open(js_fn, 'r') as js_fd:
+            return json.load(js_fd)
+
+     # create test file
+    (fd, filename) = tempfile.mkstemp()
+    os.write(fd, '{ "deleteme" : 1, "spareme" : { "deletemetoo" : 1 } }')
+    os.close(fd)
+    self.assert_(os.path.exists(filename))
+    self.assertEqual(load_js(filename), { 'deleteme' : 1, 'spareme' : { 'deletemetoo' : 1 } } )
+
+    # invalid key
+    execute(filename, 'doesnotexist')
+    self.assertEqual(load_js(filename), { 'deleteme' : 1, 'spareme' : { 'deletemetoo' : 1 } } )
+
+    # invalid key
+    execute(filename, 'deleteme/doesnotexist')
+    self.assertEqual(load_js(filename), { 'deleteme' : 1, 'spareme' : { 'deletemetoo' : 1 } } )
+
+    # valid key
+    execute(filename, 'deleteme')
+    self.assertEqual(load_js(filename), { 'spareme' : { 'deletemetoo' : 1 } } )
+
+    # valid key
+    execute(filename, 'spareme/deletemetoo')
+    self.assertEqual(load_js(filename), { 'spareme' : {} } )
+
+    # valid key
+    execute(filename, 'spareme')
+    self.assertEqual(load_js(filename), { } )
+
+    # clean up
+    delete(filename)
+    self.assert_(not os.path.exists(filename))
 
 
 class FileUtilitiesTestCase(unittest.TestCase):
@@ -126,6 +205,16 @@ class FileUtilitiesTestCase(unittest.TestCase):
         os.rmdir(dirname)
 
 
+    def test_clean_ini(self):
+        """Unit test for clean_ini()"""
+        test_ini_helper(self, clean_ini)
+
+
+    def test_clean_json(self):
+        """Unit test for clean_json()"""
+        test_json_helper(self, clean_json)
+
+
     def test_delete(self):
         """Unit test for method delete()"""
         print "testing delete() with shred = False"
@@ -209,6 +298,12 @@ class FileUtilitiesTestCase(unittest.TestCase):
         delete(filename, shred)
         self.assert_(not os.path.exists(filename))
 
+        # test directory
+        path = tempfile.mkdtemp()
+        self.assert_(os.path.exists(path))
+        delete(path, shred)
+        self.assert_(not os.path.exists(path))
+
 
     def test_ego_owner(self):
         """Unit test for ego_owner()"""
@@ -248,6 +343,15 @@ class FileUtilitiesTestCase(unittest.TestCase):
             expand_glob_join('c:\windows', '*.exe')
 
 
+    def test_free_space(self):
+        """Unit test for free_space()"""
+        home = os.path.expanduser("~")
+        result = free_space(home)
+        self.assertNotEqual(result, None)
+        self.assert_(result > -1)
+        self.assert_(isinstance(result, (int, long)))
+
+
     def test_getsize(self):
         """Unit test for method getsize()"""
         # create regular file
@@ -381,6 +485,66 @@ class FileUtilitiesTestCase(unittest.TestCase):
         os.remove(filename)
 
 
+    def wipe_name_helper(self, filename):
+        """Helper for test_wipe_name()"""
+
+        self.assert_(os.path.exists(filename))
+
+        # test
+        newname = wipe_name(filename)
+        self.assert_(len(filename) > len(newname))
+        self.assert_(not os.path.exists(filename))
+        self.assert_(os.path.exists(newname))
+
+        # clean
+        os.remove(newname)
+        self.assert_(not os.path.exists(newname))
+
+
+    def test_wipe_name(self):
+        """Unit test for wipe_name()"""
+
+         # create test file with moderately long name
+        (handle, filename) = tempfile.mkstemp("wipetest" + "0" * 50)
+        os.close(handle)
+        self.wipe_name_helper(filename)
+
+        # create file with short name in temporary directory with long name
+        if 'posix' == os.name:
+            dir0len = 210
+            dir1len = 210
+            filelen = 10
+        if 'nt' == os.name:
+            # In Windows, the maximum path length is 260 characters
+            # http://msdn.microsoft.com/en-us/library/aa365247%28VS.85%29.aspx#maxpath
+            dir0len = 100
+            dir1len = 5
+            filelen = 10
+
+        dir0 = tempfile.mkdtemp(suffix = "0" * dir0len)
+        self.assert_(os.path.exists(dir0))
+
+        dir1 = tempfile.mkdtemp(suffix = "1" * dir1len, dir = dir0)
+        self.assert_(os.path.exists(dir1))
+
+        (handle, filename) = tempfile.mkstemp(dir = dir1, suffix = "2" * filelen)
+        os.close(handle)
+        self.wipe_name_helper(filename)
+        self.assert_(os.path.exists(dir0))
+        self.assert_(os.path.exists(dir1))
+
+        # wipe a directory name
+        dir1new = wipe_name(dir1)
+        self.assert_(len(dir1) > len(dir1new))
+        self.assert_(not os.path.exists(dir1))
+        self.assert_(os.path.exists(dir1new))
+        os.rmdir(dir1new)
+
+        # wipe the directory
+        os.rmdir(dir0)
+        self.assert_(not os.path.exists(dir0))
+
+
     def test_wipe_path(self):
         """Unit test for wipe_path()"""
         if None == os.getenv('ALLTESTS'):
@@ -438,7 +602,7 @@ class FileUtilitiesTestCase(unittest.TestCase):
             "openfiles.last_scan_time (ago)=%s\n" \
             "openfiles.files=%s" % \
             (filename, \
-            datetime.datetime.now() - openfiles.last_scan_time, \
+            time.time() - openfiles.last_scan_time, \
             openfiles.files))
 
         f = os.fdopen(handle)
