@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -121,12 +121,20 @@ class WindowsTestCase(unittest.TestCase):
         self.assertEqual(delete_registry_value('HKCU\\doesnotexist', value_name, True), False)
 
 
+    def test_detect_registry_key(self):
+        """Test for detect_registry_key()"""
+        self.assert_(detect_registry_key('HKCU\\Software\\Microsoft\\'))
+        self.assert_(not detect_registry_key('HKCU\\Software\\DoesNotExist'))
+
+
     def test_enumerate_processes(self):
         def tep_helper(processes):
             for process in processes:
                 self.assertEqual(process, process.lower())
                 self.assert_(len(process) > 0)
                 self.assert_(isinstance(process, (str, unicode)))
+                self.assertNotEqual(process, '?')
+                self.assertNotEqual(process, '_')
             self.assert_('explorer.exe' in processes)
         tep_helper(enumerate_processes())
         tep_helper(enumerate_processes_win32())
