@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 ## BleachBit
-## Copyright (C) 2010 Andrew Ziem
+## Copyright (C) 2011 Andrew Ziem
 ## http://bleachbit.sourceforge.net
 ##
 ## This program is free software: you can redistribute it and/or modify
@@ -50,20 +50,59 @@ class WorkerTestCase(unittest.TestCase):
         cleaner = TestCleaner.action_to_cleaner(astr)
         backends['test'] = cleaner
         operations = { 'test' : [ 'option1' ] }
-        w = Worker(ui, True, operations)
-        run = w.run()
+        worker = Worker(ui, True, operations)
+        run = worker.run()
         while run.next():
             pass
         self.assert_(not os.path.exists(filename), \
             "Path still exists '%s'" % filename)
-        self.assertEqual(w.total_special, 3)
-        self.assertEqual(w.total_errors, 2)
+        self.assertEqual(worker.total_special, 3)
+        self.assertEqual(worker.total_errors, 2)
         if 'posix' == os.name:
-            self.assertEqual(w.total_bytes, 4096+10+10)
-            self.assertEqual(w.total_deleted, 3)
+            self.assertEqual(worker.total_bytes, 4096+10+10)
+            self.assertEqual(worker.total_deleted, 3)
         elif 'nt' == os.name:
-            self.assertEqual(w.total_bytes, 3+3+10+10)
-            self.assertEqual(w.total_deleted, 4)
+            self.assertEqual(worker.total_bytes, 3+3+10+10)
+            self.assertEqual(worker.total_deleted, 4)
+
+
+    def test_deep_scan(self):
+        """Test for deep scan"""
+
+        # load cleaners from XML
+        import bleachbit.CleanerML
+        bleachbit.CleanerML.load_cleaners()
+
+        # DeepScan itself is tested elsewhere, so replace it here
+        import bleachbit.DeepScan
+        SaveDeepScan = bleachbit.DeepScan.DeepScan
+        self.scanned = 0
+        self_assertequal = self.assertEqual
+        self_assert = self.assert_
+
+        def increment_count():
+            self.scanned = self.scanned + 1
+
+        class MyDeepScan:
+            def add_search(self, dirname, regex):
+                self_assertequal(dirname, os.path.expanduser('~'))
+                self_assert(regex in ('^Thumbs\\.db$', '^Thumbs\\.db:encryptable$'))
+
+            def scan(self):
+                increment_count()
+                yield True
+        bleachbit.DeepScan.DeepScan = MyDeepScan
+
+        # test
+        operations = { 'deepscan' : [ 'thumbs_db' ] }
+        ui = CLI.CliCallback()
+        worker = Worker(ui, False, operations).run()
+        while worker.next():
+            pass
+        self.assertEqual(1, self.scanned)
+
+        # clean up
+        bleachbit.DeepScan.DeepScan = SaveDeepScan
 
 
     def test_multiple_options(self):
@@ -81,17 +120,17 @@ class WorkerTestCase(unittest.TestCase):
         cleaner = TestCleaner.actions_to_cleaner([astr1, astr2])
         backends['test'] = cleaner
         operations = { 'test' : [ 'option1', 'option2' ] }
-        w = Worker(ui, True, operations)
-        run = w.run()
+        worker = Worker(ui, True, operations)
+        run = worker.run()
         while run.next():
             pass
         self.assert_(not os.path.exists(filename1), \
             "Path still exists '%s'" % filename1)
         self.assert_(not os.path.exists(filename2), \
             "Path still exists '%s'" % filename2)
-        self.assertEqual(w.total_special, 0)
-        self.assertEqual(w.total_errors, 0)
-        self.assertEqual(w.total_deleted, 2)
+        self.assertEqual(worker.total_special, 0)
+        self.assertEqual(worker.total_errors, 0)
+        self.assertEqual(worker.total_deleted, 2)
 
 
 
